pub struct ConformanceClient { /* private fields */ }Expand description
Conformance testing API client
Implementations
Sourceimpl ConformanceClient
impl ConformanceClient
Sourcepub fn new(base_url: impl Into<String>) -> Self
pub fn new(base_url: impl Into<String>) -> Self
Create a new conformance client
The base URL should be the admin API root (e.g., http://localhost:9080).
Sourcepub async fn run(&self, config: ConformanceRunRequest) -> Result<Uuid>
pub async fn run(&self, config: ConformanceRunRequest) -> Result<Uuid>
Start a new conformance test run
Returns the UUID of the newly created run.
Sourcepub async fn get_status(&self, id: Uuid) -> Result<ConformanceRun>
pub async fn get_status(&self, id: Uuid) -> Result<ConformanceRun>
Get the status and results of a conformance run
Sourcepub async fn get_report(&self, id: Uuid) -> Result<Value>
pub async fn get_report(&self, id: Uuid) -> Result<Value>
Get the report for a completed conformance run
Returns the report JSON if the run is completed, or an error if not yet done.
Sourcepub async fn list_runs(&self) -> Result<Vec<ConformanceRunSummary>>
pub async fn list_runs(&self) -> Result<Vec<ConformanceRunSummary>>
List all conformance runs
Sourcepub async fn delete_run(&self, id: Uuid) -> Result<()>
pub async fn delete_run(&self, id: Uuid) -> Result<()>
Delete a completed conformance run